@@ -818,7 +818,7 @@ var nsDefaultCommandLineHandler = {
   },
 
   // XXX localize me... how?
-  helpInfo : "Usage: firefox [-flags] [<url>]\n",
+  helpInfo : " Usage: icecat [-flags] [<url>]\n",
 
   /* nsIFactory */
   createInstance: function dch_CI(outer, iid) {
