@@ -17,7 +17,7 @@
  *
  * The Initial Developer of the Original Code is
  * Mozilla Foundation.
- * Portions created by the Initial Developer are Copyright (C) 2008
+ * Portions created by the Initial Developer are Copyright (C) 2006
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s): Igor Bukanov
@@ -36,29 +36,29 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = 'regress-458679-01.js';
+gTestfile = 'regress-356238-03.js';
 
-var summary = 'GetXMLEntity should not assume FastAppendChar is infallible';
-var BUGNUMBER = 458679;
-var actual = '';
-var expect = '';
+var BUGNUMBER = 356238;
+var summary = 'bug 356238';
+var actual = 'No Error';
+var expect = 'No Error';
 
 printBugNumber(BUGNUMBER);
 START(summary);
 
-try
-{
-    var x = "<";
+var xml = <xml><child><a/></child></xml>;
+var child = xml.child[0];
 
-    while (x.length < 12000000)
-        x += x;
+try {
+  child.insertChildBefore(null, xml.child);
+  actual = "insertChildBefore succeded when it should throw an exception";
+} catch (e) {
+}
 
-    <e4x>{x}</e4x>;
-}
-catch(ex)
-{
-}
+var list = child.*;
+var text = uneval(list[1]);
+if (!/(undefined|\(void 0\))/.test(text))
+  throw "child got unexpected second element: "+text;
 
 TEST(1, expect, actual);
-
 END();
