@@ -40,37 +40,38 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '13.4.4.4.js';
+gTestfile = '13.4.4.34.js';
 
-START("13.4.4.4 - XML attribute()");
+START("13.4.4.34 - XML setLocalName()");
 
-TEST(1, true, XML.prototype.hasOwnProperty("attribute"));
+TEST(1, true, XML.prototype.hasOwnProperty("setLocalName"));
 
-// Get count of employees
-emps =
-<employees count="2">
-    <employee id="0"><name>Jim</name><age>25</age></employee>
-    <employee id="1"><name>Joe</name><age>20</age></employee>
-</employees>;
+x =
+<alpha>
+    <bravo>one</bravo>
+</alpha>;
 
-TEST_XML(2, 2, emps.attribute("count"));
+correct =
+<charlie>
+    <bravo>one</bravo>
+</charlie>;
 
-// Get the id of the employee age 25
-emps =
-<employees>
-    <employee id="0"><name>Jim</name><age>25</age></employee>
-    <employee id="1"><name>Joe</name><age>20</age></employee>
-</employees>;
+x.setLocalName("charlie");
 
-TEST_XML(3, 0, emps.employee.(age == "25").attribute("id"));
+TEST(2, correct, x);
 
-// Get the id of the employee named Jim
-emps =
-<employees>
-    <employee id="0"><name>Jim</name><age>25</age></employee>
-    <employee id="1"><name>Joe</name><age>20</age></employee>
-</employees>;
+x =
+<ns:alpha xmlns:ns="http://foobar/">
+    <ns:bravo>one</ns:bravo>
+</ns:alpha>;
 
-TEST_XML(4, 0, emps.employee.(name == "Jim").attribute("id"));
+correct =
+<ns:charlie xmlns:ns="http://foobar/">
+    <ns:bravo>one</ns:bravo>
+</ns:charlie>;
 
-END();
+x.setLocalName("charlie");
+
+TEST(3, correct, x);
+
+END();
\ No newline at end of file
