@@ -16,10 +16,10 @@
  *
  * The Initial Developer of the Original Code is
  * Mozilla Foundation.
- * Portions created by the Initial Developer are Copyright (C) 2006
+ * Portions created by the Initial Developer are Copyright (C) 2008
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s):
+ * Contributor(s): Jesse Ruderman
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,31 +35,27 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-360969-06.js';
+var gTestfile = 'regress-355829-01.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 360969;
-var summary = '2^17: global function';
-var actual = 'No Crash';
-var expect = 'No Crash';
+var BUGNUMBER = 355829;
+var summary = 'Do not assert: !argc || JSVAL_IS_NULL(argv[0]) || JSVAL_IS_VOID(argv[0])';
+var actual = '';
+var expect = '';
 
-var global = this;
 
-printBugNumber(BUGNUMBER);
-printStatus (summary);
- 
-var start = new Date();
-var p;
-var i;
-var limit = 2 << 16;
+//-----------------------------------------------------------------------------
+test();
+//-----------------------------------------------------------------------------
 
-for (var i = 0; i < limit; i++)
+function test()
 {
-  eval('function pf' + i + '() {}');
+  enterFunc ('test');
+  printBugNumber(BUGNUMBER);
+  printStatus (summary);
+
+  new Object({valueOf: /a/});
+
+  reportCompare(expect, actual, summary);
+
+  exitFunc ('test');
 }
-
-reportCompare(expect, actual, summary);
-
-var stop = new Date();
-
-print('Elapsed time: ' + Math.floor((stop - start)/1000) + ' seconds');
-
