@@ -16,10 +16,10 @@
  *
  * The Initial Developer of the Original Code is
  * Mozilla Foundation.
- * Portions created by the Initial Developer are Copyright (C) 2008
+ * Portions created by the Initial Developer are Copyright (C) 2007
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s): Brendan Eich 
+ * Contributor(s): Igor Bukanov
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,46 +35,16 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-452498-191.js';
+var gTestfile = 'regress-407727-01.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 452498;
-var summary = 'TM: upvar2 regression tests';
+var BUGNUMBER = 407727;
+var summary = 'let Object global redeclaration';
 var actual = '';
-var expect = '';
+var expect = 1;
 
-//-------  Comment #191  From  Brendan Eich
-
-//-----------------------------------------------------------------------------
-test();
-//-----------------------------------------------------------------------------
-
-function test()
-{
-  enterFunc ('test');
-  printBugNumber(BUGNUMBER);
-  printStatus (summary);
-
-  expect = actual = 'No Error';
-  try
-  {
-    eval('{ var x; {let x;} }');
-  }
-  catch(ex)
-  {
-    actual = ex + '';
-  }
-  reportCompare(expect, actual, summary);
-
-  expect = 'TypeError: redeclaration of let x';
-  try
-  {
-    eval('{ let x; {var x;} }');
-  }
-  catch(ex)
-  {
-    actual = ex + '';
-  }
-  reportCompare(expect, actual, summary);
-
-  exitFunc ('test');
-}
+printBugNumber(BUGNUMBER);
+printStatus (summary);
+ 
+let Object = 1;
+actual = Object;
+reportCompare(expect, actual, summary);
