@@ -16,10 +16,10 @@
  *
  * The Initial Developer of the Original Code is
  * Mozilla Foundation.
- * Portions created by the Initial Developer are Copyright (C) 2007
+ * Portions created by the Initial Developer are Copyright (C) 2008
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s): Jesse Ruderman
+ * Contributor(s): Gary Kwong
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,13 +35,13 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-385393-02.js';
-
+var gTestfile = 'regress-437288-01.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 385393;
-var summary = 'Regression test for bug 385393';
-var actual = 'No Crash';
-var expect = 'No Crash';
+var BUGNUMBER = 437288;
+var summary = 'for loop turning into a while loop';
+var actual = 'No Hang';
+var expect = 'No Hang';
+
 
 //-----------------------------------------------------------------------------
 test();
@@ -52,13 +52,15 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
- 
+
+  expect = 'SyntaxError: invalid for/in left-hand side';
   try
   {
-    (4).__lookupGetter__("w");
+    eval('(function() { const x = 1; for (x in null); })();');
   }
   catch(ex)
   {
+    actual = ex + '';
   }
 
   reportCompare(expect, actual, summary);
